using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Data.SqlClient;
using System.Xml;
using ToolsAndMore;

public partial class _XmlXbrl : System.Web.UI.Page 
{
    protected void Page_Load(object sender, System.EventArgs e)
    {
        // Code will be executed if the page load not is a post back
        if (!Page.IsPostBack)
        {
            // When the page loads we get the user id from a session variable and saves this in a hidden field
            HiddenUserID.Value = Convert.ToString(Session["UserID"]);
        }
    }

    protected void Write_XML(object sender, WizardNavigationEventArgs e)
    {
        // Create the url for the xml-file to be saved in the database, we use a function in Tools.vb to replace
        // symbols. Look in Tools.cs to see the code.

        string xbrlurl = "xbrl/" + Tools.ReplaceSymbols(txtFirma.Text) + Tools.ReplaceSymbols(DateTime.Now.ToString()) + ".xbrl";

        // Save the url for the XML-file to the XML-files table in the database so the user can see and download the XML-files 
        // that the user have saved on our server.

        try
        {
            string ConnString = ConfigurationManager.ConnectionStrings["ConnectionString"].ToString();
            string sql = "INSERT INTO XML-files (URL, Company, StartDate, EndDate, UserID, Date) VALUES "
            + "(@URL, @Company, @StartDate, @EndDate, @UserID, @Date)";

            // The using block is used to call dispose (close) automatically even if there are an exception.
            using (SqlConnection cn = new SqlConnection(ConnString))
            {
                // The using block is used to call dispose (close) automatically even if there are an exception.
                using (SqlCommand cmd = new SqlCommand(sql, cn))
                {
                    cmd.Parameters.AddWithValue("@URL", xbrlurl);
                    cmd.Parameters.AddWithValue("@Company", txtFirma.Text);
                    cmd.Parameters.AddWithValue("@StartDate", txtRakenskapsarStartDatePeriod0.Text);
                    cmd.Parameters.AddWithValue("@EndDate", txtRakenskapsarEndDatePeriod0.Text);
                    cmd.Parameters.AddWithValue("@UserID", HiddenUserID.Value);
                    cmd.Parameters.AddWithValue("@Date", DateTime.Now.ToString());

                    // Open the connection.
                    cn.Open();

                    // Execute the INSERT statement.
                    cmd.ExecuteNonQuery();
                }
            }
        }
        catch (Exception ex)
        {
            Response.Write(ex.Message);
        }

        // Create an XML-document with the right encoding and saves this xml-file to our 
        // server according to the "xbrlurl" above.

        XmlTextWriter textWriter = new XmlTextWriter(Server.MapPath(xbrlurl), System.Text.Encoding.UTF8 );
        textWriter.Formatting = System.Xml.Formatting.Indented;

        // IF WE DONT WANT TO SAVE THE XML-FILE ON THE SERVER WE COULD USE THIS CODE INSTEAD SO THAT
        // THE USER COULD DOWNLOAD THE FILE TO HIS LOCAL COMPUTER
        //XmlTextWriter textWriter = new XmlTextWriter(Response.OutputStream, new UTF8Encoding(false));
        //textWriter.Formatting = System.Xml.Formatting.Indented;

        //Start new document
        textWriter.WriteStartDocument();

        //Insert XBRL start row, Start Element with attributes
        textWriter.WriteStartElement("xbrli:xbrl");
        textWriter.WriteAttributeString("xmlns:se-cd-base", "http://www.xbrl.se/se/fr/cd-base/2007-05-25");
        textWriter.WriteAttributeString("xmlns:link", "http://www.xbrl.org/2003/linkbase");
        textWriter.WriteAttributeString("xmlns:se-gen-base", "http://www.xbrl.se/se/fr/gen-base/2007-05-25");
        textWriter.WriteAttributeString("xmlns:bve", "http://www.bolagsverket.se/xbrl/types/2006-05-25");
        textWriter.WriteAttributeString("xmlns:iso4217", "http://www.xbrl.org/2003/iso4217");
        textWriter.WriteAttributeString("xmlns:xlink", "http://www.w3.org/1999/xlink");
        textWriter.WriteAttributeString("xmlns:xbrli", "http://www.xbrl.org/2003/instance");

        //Insert XBRL link scheme
        if (string.IsNullOrEmpty(BruttoresultatRES0.Text))
        {
            textWriter.WriteElementString("link:schemaRef xlink:type=\"simple\" xlink:href=\"http://taxonomi.xbrl.se/se/fr/sme/rbn/2008-09-30/se-sme-rbn-2008-09-30.xsd\"", "");
        }
        else
        {
            textWriter.WriteElementString("link:schemaRef xlink:type=\"simple\" xlink:href=\"http://taxonomi.xbrl.se/se/fr/sme/rbf/2008-09-30/se-sme-rbf-2008-09-30.xsd\"", "");
        }

        //Insert Start Element for PERIOD0 with attributeString
        textWriter.WriteStartElement("xbrli:context");
        textWriter.WriteAttributeString("id", "PERIOD0");

        //Insert entity inside PERIOD0 xbrli:context
        textWriter.WriteStartElement("xbrli:entity");
        textWriter.WriteStartElement("xbrli:identifier", "");
        textWriter.WriteAttributeString("scheme", "http://www.bolagsverket.se");
        textWriter.WriteString(txtOrganisationsnummer.Text);
        textWriter.WriteEndElement();
        textWriter.WriteEndElement();

        //Insert period inside PERIOD0 xbrli:context
        textWriter.WriteStartElement("xbrli:period");
        textWriter.WriteStartElement("xbrli:startDate", "");
        textWriter.WriteString(txtRakenskapsarStartDatePeriod0.Text);
        textWriter.WriteEndElement();
        textWriter.WriteStartElement("xbrli:endDate", "");
        textWriter.WriteString(txtRakenskapsarEndDatePeriod0.Text);
        textWriter.WriteEndElement();
        textWriter.WriteEndElement();

        //Insert End Element for PERIOD0
        textWriter.WriteEndElement();

        if (!string.IsNullOrEmpty(txtRakenskapsarStartDatePeriodm1.Text))
        {
            //Insert Start Element for PERIOD-1 with attributeString
            textWriter.WriteStartElement("xbrli:context");
            textWriter.WriteAttributeString("id", "PERIOD-1");
            //Insert entity inside PERIOD-1 xbrli:context
            textWriter.WriteStartElement("xbrli:entity");
            textWriter.WriteStartElement("xbrli:identifier", "");
            textWriter.WriteAttributeString("scheme", "http://www.bolagsverket.se");
            textWriter.WriteString(txtOrganisationsnummer.Text);
            textWriter.WriteEndElement();
            textWriter.WriteEndElement();
            //Insert period inside PERIOD-1 xbrli:context
            textWriter.WriteStartElement("xbrli:period");
            textWriter.WriteStartElement("xbrli:startDate", "");
            textWriter.WriteString(txtRakenskapsarStartDatePeriodm1.Text);
            textWriter.WriteEndElement();
            textWriter.WriteStartElement("xbrli:endDate", "");
            textWriter.WriteString(txtRakenskapsarEndDatePeriodm1.Text);
            textWriter.WriteEndElement();
            textWriter.WriteEndElement();
            //Insert End Element for PERIOD-1
            textWriter.WriteEndElement();
        }

        //Insert Start Element for BALANS0 with attributeString
        textWriter.WriteStartElement("xbrli:context");
        textWriter.WriteAttributeString("id", "BALANS0");
        //Insert entity inside BALANS0 xbrli:context
        textWriter.WriteStartElement("xbrli:entity");
        textWriter.WriteStartElement("xbrli:identifier", "");
        textWriter.WriteAttributeString("scheme", "http://www.bolagsverket.se");
        textWriter.WriteString(txtOrganisationsnummer.Text);
        textWriter.WriteEndElement();
        textWriter.WriteEndElement();
        //Insert period inside BALANS0 xbrli:context
        textWriter.WriteStartElement("xbrli:period");
        textWriter.WriteStartElement("xbrli:instant", "");
        textWriter.WriteString(txtRakenskapsarEndDatePeriod0.Text);
        textWriter.WriteEndElement();
        textWriter.WriteEndElement();
        //Insert End Element for BALANS0
        textWriter.WriteEndElement();

        //Insert Start Element for BALANS-1 with attributeString
        if (!string.IsNullOrEmpty(txtRakenskapsarStartDatePeriodm1.Text))
        {
            textWriter.WriteStartElement("xbrli:context");
            textWriter.WriteAttributeString("id", "BALANS-1");
            //Insert entity inside BALANS-1 xbrli:context
            textWriter.WriteStartElement("xbrli:entity");
            textWriter.WriteStartElement("xbrli:identifier", "");
            textWriter.WriteAttributeString("scheme", "http://www.bolagsverket.se");
            textWriter.WriteString(txtOrganisationsnummer.Text);
            textWriter.WriteEndElement();
            textWriter.WriteEndElement();
            //Insert period inside BALANS-1 xbrli:context
            textWriter.WriteStartElement("xbrli:period");
            textWriter.WriteStartElement("xbrli:instant", "");
            textWriter.WriteString(txtRakenskapsarEndDatePeriodm1.Text);
            textWriter.WriteEndElement();
            textWriter.WriteEndElement();
            //Insert End Element for BALANS-1
            textWriter.WriteEndElement();
        }

        //Insert Start Element for Valuta
        textWriter.WriteStartElement("xbrli:unit");
        textWriter.WriteAttributeString("id", "valuta");
        //Insert measure inside Valuta
        textWriter.WriteStartElement("xbrli:measure");
        textWriter.WriteString("iso4217:" + txtRedovisningsvaluta.SelectedValue);
        textWriter.WriteEndElement();
        //Insert End Element for Valuta
        textWriter.WriteEndElement();

        //Insert Start Element for Andelar
        textWriter.WriteStartElement("xbrli:unit");
        textWriter.WriteAttributeString("id", "andelar");
        //Insert measure inside Andelar
        textWriter.WriteStartElement("xbrli:measure");
        textWriter.WriteString("xbrli:shares");
        textWriter.WriteEndElement();
        //Insert End Element for Andelar
        textWriter.WriteEndElement();

        //Insert Start Element for Procent
        textWriter.WriteStartElement("xbrli:unit");
        textWriter.WriteAttributeString("id", "procent");
        //Insert measure inside Procent
        textWriter.WriteStartElement("xbrli:measure");
        textWriter.WriteString("xbrli:pure");
        textWriter.WriteEndElement();
        //Insert End Element for Procent
        textWriter.WriteEndElement();

        //Insert Start Element for Antal
        textWriter.WriteStartElement("xbrli:unit");
        textWriter.WriteAttributeString("id", "antal");
        //Insert measure inside Antal
        textWriter.WriteStartElement("xbrli:measure");
        textWriter.WriteString("bve:antal");
        textWriter.WriteEndElement();
        //Insert End Element for Antal
        textWriter.WriteEndElement();

        //Insert Elements for Firma
        textWriter.WriteStartElement("se-cd-base:Firma");
        textWriter.WriteAttributeString("contextRef", "PERIOD0");
        textWriter.WriteString(txtFirma.Text);
        textWriter.WriteEndElement();

        //Insert Elements for Organisationsnummer
        textWriter.WriteStartElement("se-cd-base:Organisationsnummer");
        textWriter.WriteAttributeString("contextRef", "PERIOD0");
        textWriter.WriteString(txtOrganisationsnummer.Text);
        textWriter.WriteEndElement();

        //Insert Elements for Sprak
        textWriter.WriteStartElement("se-cd-base:Sprak");
        textWriter.WriteAttributeString("contextRef", "PERIOD0");
        textWriter.WriteString("sv");
        textWriter.WriteEndElement();

        //Insert Elements for Land
        textWriter.WriteStartElement("se-cd-base:Land");
        textWriter.WriteAttributeString("contextRef", "PERIOD0");
        textWriter.WriteString("SE");
        textWriter.WriteEndElement();

        //Insert Elements for Beloppsformat
        textWriter.WriteStartElement("se-cd-base:Beloppsformat");
        textWriter.WriteAttributeString("contextRef", "PERIOD0");
        textWriter.WriteString(txtBeloppsformat.SelectedValue);
        textWriter.WriteEndElement();

        //Insert Elements for Redovisningsvaluta
        textWriter.WriteStartElement("se-cd-base:Redovisningsvaluta");
        textWriter.WriteAttributeString("contextRef", "PERIOD0");
        textWriter.WriteString(txtRedovisningsvaluta.SelectedValue);
        textWriter.WriteEndElement();

        //Insert Elements for Verksamhetsbeskrivning i Forvaltningsberattelsen
        if (!string.IsNullOrEmpty(txtVerksamheten.Text))
        {
            textWriter.WriteStartElement("se-gen-base:Verksamheten");
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteString(txtVerksamheten.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Vasentliga Handelser i Forvaltningsberattelsen
        if (!string.IsNullOrEmpty(txtVasantligaHandelser.Text))
        {
            textWriter.WriteStartElement("se-gen-base:VasentligaHandelserUnderOchEfterRakenskapsaretsSlut");
            textWriter.WriteAttributeString("contextRef", "BALANS0");
            textWriter.WriteString(txtVasantligaHandelser.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Framtida Utveckling i Forvaltningsberattelsen
        if (!string.IsNullOrEmpty(txtFramtidaUtveckling.Text))
        {
            textWriter.WriteStartElement("se-gen-base:FramtidaUtveckling");
            textWriter.WriteAttributeString("contextRef", "BALANS0");
            textWriter.WriteString(txtFramtidaUtveckling.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for MiljoPaverkan i Forvaltningsberattelsen
        if (!string.IsNullOrEmpty(txtMiljoPaverkan.Text))
        {
            textWriter.WriteStartElement("se-gen-base:Miljopaverkan");
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteString(txtMiljoPaverkan.Text);
            textWriter.WriteEndElement();
        }

        /////////////////////////////// Medel att disponera //////////////////////////////////

        //Insert Elements for Medel att disponera Overkursfond
        if (!string.IsNullOrEmpty(MedelAttDisponeraOverkursfond.Text))
        {
            textWriter.WriteStartElement("se-gen-base:MedelAttDisponeraOverkursfond");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "BALANS0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(MedelAttDisponeraOverkursfond.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Medel att disponera Fond for verkligt varde
        if (!string.IsNullOrEmpty(MedelAttDisponeraFondForVerkligtVarde.Text))
        {
            textWriter.WriteStartElement("se-gen-base:MedelAttDisponeraFondForVerkligtVarde");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "BALANS0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(MedelAttDisponeraFondForVerkligtVarde.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Medel att disponera Balanserat resultat
        if (!string.IsNullOrEmpty(MedelAttDisponeraBalanseratResultat.Text))
        {
            textWriter.WriteStartElement("se-gen-base:MedelAttDisponeraBalanseratResultat");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "BALANS0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(MedelAttDisponeraBalanseratResultat.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Medel att disponera Koncernbidrag
        if (!string.IsNullOrEmpty(MedelAttDisponeraKoncernbidrag.Text))
        {
            textWriter.WriteStartElement("se-gen-base:MedelAttDisponeraKoncernbidrag");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "BALANS0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(MedelAttDisponeraKoncernbidrag.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Medel att disponera Erhallna aktieagartillskott
        if (!string.IsNullOrEmpty(MedelAttDisponeraErhallnaAktieagartillskott.Text))
        {
            textWriter.WriteStartElement("se-gen-base:MedelAttDisponeraErhallnaAktieagartillskott");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "BALANS0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(MedelAttDisponeraErhallnaAktieagartillskott.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Medel att disponera Arets resultat
        if (!string.IsNullOrEmpty(MedelAttDisponeraAretsResultat.Text))
        {
            textWriter.WriteStartElement("se-gen-base:MedelAttDisponeraAretsResultat");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "BALANS0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(MedelAttDisponeraAretsResultat.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Medel att disponera Summa
        if (!string.IsNullOrEmpty(MedelAttDisponeraSumma.Text))
        {
            textWriter.WriteStartElement("se-gen-base:MedelAttDisponera");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "BALANS0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(MedelAttDisponeraSumma.Text);
            textWriter.WriteEndElement();
        }

        /////////////////////////////// Forslag till disposition //////////////////////////////////

        //Insert Elements for Forslag till disposition Utdelning
        if (!string.IsNullOrEmpty(ForslagDispositionUtdelning.Text))
        {
            textWriter.WriteStartElement("se-gen-base:ForslagDispositionUtdelning");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "BALANS0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(ForslagDispositionUtdelning.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Forslag till disposition Fondemission
        if (!string.IsNullOrEmpty(ForslagDispositionFondemission.Text))
        {
            textWriter.WriteStartElement("se-gen-base:ForslagDispositionFondemission");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "BALANS0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(ForslagDispositionFondemission.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Forslag till disposition Avsattning till reservfond
        if (!string.IsNullOrEmpty(ForslagDispositionAvsattningTillReservfond.Text))
        {
            textWriter.WriteStartElement("se-gen-base:ForslagDispositionAvsattningReservfond");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "BALANS0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(ForslagDispositionAvsattningTillReservfond.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Forslag till disposition Ianspraktagande av reservfond
        if (!string.IsNullOrEmpty(ForslagDispositionIanspraktagandeAvReservFond.Text))
        {
            textWriter.WriteStartElement("se-gen-base:ForslagDispositionIanspraktagandeAvReservfond");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "BALANS0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(ForslagDispositionIanspraktagandeAvReservFond.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Forslag till disposition Ianspraktagande av uppskrivningsfond
        if (!string.IsNullOrEmpty(ForslagDispositionIanspraktagandeAvUppskrivningsfond.Text))
        {
            textWriter.WriteStartElement("se-gen-base:ForslagDispositionIanspraktagandeAvUppskrivningsfond");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "BALANS0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(ForslagDispositionIanspraktagandeAvUppskrivningsfond.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Forslag till disposition Balanseras i ny rakning
        if (!string.IsNullOrEmpty(ForslagDispositionBalanserasINyRakning.Text))
        {
            textWriter.WriteStartElement("se-gen-base:ForslagDispositionBalanserasINyRakning");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "BALANS0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(ForslagDispositionBalanserasINyRakning.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Forslag till disposition Summa
        if (!string.IsNullOrEmpty(ForslagDispositionSumma.Text))
        {
            textWriter.WriteStartElement("se-gen-base:ForslagDispositionSumma");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "BALANS0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(ForslagDispositionSumma.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Kommentar till dispositioner
        if (!string.IsNullOrEmpty(txtKommentarDispositioner.Text))
        {
            textWriter.WriteStartElement("se-gen-base:DispositionerVinstEllerForlustKommentar");
            textWriter.WriteAttributeString("contextRef", "BALANS0");
            textWriter.WriteString(txtKommentarDispositioner.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Styrelsens yttrande om vinstutdelning
        if (!string.IsNullOrEmpty(StyrelsensYttrandeVinstutdelning.Text))
        {
            textWriter.WriteStartElement("se-gen-base:StyrelsensYttrandeVinstutdelning");
            textWriter.WriteAttributeString("contextRef", "BALANS0");
            textWriter.WriteString(StyrelsensYttrandeVinstutdelning.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultat och stallning
        if (!string.IsNullOrEmpty(ResultatOchStallning.Text))
        {
            textWriter.WriteStartElement("se-gen-base:ResultatOchStallning");
            textWriter.WriteAttributeString("contextRef", "BALANS0");
            textWriter.WriteString(ResultatOchStallning.Text);
            textWriter.WriteEndElement();
        }

        /////////////////////////////// Resultatrakning //////////////////////////////////

        //Insert Elements for Resultatrakning Nettoomsattning Period 0
        if (!string.IsNullOrEmpty(NettoomsattningRES0.Text))
        {
            textWriter.WriteStartElement("se-gen-base:Nettoomsattning");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(NettoomsattningRES0.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Nettoomsattning Period -1
        if (!string.IsNullOrEmpty(NettoomsattningRESm1.Text))
        {
            textWriter.WriteStartElement("se-gen-base:Nettoomsattning");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD-1");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(NettoomsattningRESm1.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Kostnad Salda Varor Period 0
        if (!string.IsNullOrEmpty(KostnadSaldaVarorRES0.Text))
        {
            textWriter.WriteStartElement("se-gen-base:KostnadSaldaVaror");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(KostnadSaldaVarorRES0.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Kostnad Salda Varor Period -1
        if (!string.IsNullOrEmpty(KostnadSaldaVarorRESm1.Text))
        {
            textWriter.WriteStartElement("se-gen-base:KostnadSaldaVaror");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD-1");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(KostnadSaldaVarorRESm1.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Bruttoresultat Period 0
        if (!string.IsNullOrEmpty(BruttoresultatRES0.Text))
        {
            textWriter.WriteStartElement("se-gen-base:Bruttoresultat");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(BruttoresultatRES0.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Bruttoresultat Period -1
        if (!string.IsNullOrEmpty(BruttoresultatRESm1.Text))
        {
            textWriter.WriteStartElement("se-gen-base:Bruttoresultat");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD-1");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(BruttoresultatRESm1.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Forsaljningskostnader Period 0
        if (!string.IsNullOrEmpty(ForsaljningskostnaderRES0.Text))
        {
            textWriter.WriteStartElement("se-gen-base:Forsaljningskostnader");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(ForsaljningskostnaderRES0.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Forsaljningskostnader Period -1
        if (!string.IsNullOrEmpty(ForsaljningskostnaderRESm1.Text))
        {
            textWriter.WriteStartElement("se-gen-base:Forsaljningskostnader");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD-1");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(ForsaljningskostnaderRESm1.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Administrationskostnader Period 0
        if (!string.IsNullOrEmpty(AdministrationskostnaderRES0.Text))
        {
            textWriter.WriteStartElement("se-gen-base:Administrationskostnader");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(AdministrationskostnaderRES0.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Administrationskostnader Period -1
        if (!string.IsNullOrEmpty(AdministrationskostnaderRESm1.Text))
        {
            textWriter.WriteStartElement("se-gen-base:Administrationskostnader");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD-1");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(AdministrationskostnaderRESm1.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Forskning utveckling Period 0
        if (!string.IsNullOrEmpty(ForskningUtvecklingRES0.Text))
        {
            textWriter.WriteStartElement("se-gen-base:ForskningsUtvecklingskostnader");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(ForskningUtvecklingRES0.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Forskning utveckling Period -1
        if (!string.IsNullOrEmpty(ForskningUtvecklingRESm1.Text))
        {
            textWriter.WriteStartElement("se-gen-base:ForskningsUtvecklingskostnader");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD-1");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(ForskningUtvecklingRESm1.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Lagerforandring Period 0
        if (!string.IsNullOrEmpty(LagerforandringRES0.Text))
        {
            textWriter.WriteStartElement("se-gen-base:ForandringAvLagerAvProdukterIArbeteFardigaVarorOchPagaendeArbetenForAnnansRakning");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(LagerforandringRES0.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Lagerforandring Period -1
        if (!string.IsNullOrEmpty(LagerforandringRESm1.Text))
        {
            textWriter.WriteStartElement("se-gen-base:ForandringAvLagerAvProdukterIArbeteFardigaVarorOchPagaendeArbetenForAnnansRakning");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD-1");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(LagerforandringRESm1.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Aktiverat arbete for egen rakning Period 0
        if (!string.IsNullOrEmpty(AktiveratArbeteForEgenRakningRES0.Text))
        {
            textWriter.WriteStartElement("se-gen-base:AktiveratArbeteForEgenRakning");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(AktiveratArbeteForEgenRakningRES0.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Aktiverat arbete for egen rakning Period -1
        if (!string.IsNullOrEmpty(AktiveratArbeteForEgenRakningRESm1.Text))
        {
            textWriter.WriteStartElement("se-gen-base:AktiveratArbeteForEgenRakning");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD-1");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(AktiveratArbeteForEgenRakningRESm1.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Ovriga rorelseintakter Period 0
        if (!string.IsNullOrEmpty(OvrigaRorelseIntakterRES0.Text))
        {
            textWriter.WriteStartElement("se-gen-base:OvrigaRorelseintakter");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(OvrigaRorelseIntakterRES0.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Ovriga rorelseintakter Period -1
        if (!string.IsNullOrEmpty(OvrigaRorelseIntakterRESm1.Text))
        {
            textWriter.WriteStartElement("se-gen-base:OvrigaRorelseintakter");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD-1");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(OvrigaRorelseIntakterRESm1.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Summa rorelseintakter Period 0
        if (!string.IsNullOrEmpty(RorelseintakterLagerforandringarMmRES0.Text))
        {
            textWriter.WriteStartElement("se-gen-base:RorelseintakterLagerforandringarMm");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(RorelseintakterLagerforandringarMmRES0.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Summa rorelseintakter Period -1
        if (!string.IsNullOrEmpty(RorelseintakterLagerforandringarMmRESm1.Text))
        {
            textWriter.WriteStartElement("se-gen-base:RorelseintakterLagerforandringarMm");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD-1");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(RorelseintakterLagerforandringarMmRESm1.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Ravaror och Fornodenheter Period 0
        if (!string.IsNullOrEmpty(RavarorOchFornodenheterResultatrakningenRES0.Text))
        {
            textWriter.WriteStartElement("se-gen-base:RavarorFornodenheterResultatrakningen");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(RavarorOchFornodenheterResultatrakningenRES0.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Ravaror och Fornodenheter Period -1
        if (!string.IsNullOrEmpty(RavarorOchFornodenheterResultatrakningenRESm1.Text))
        {
            textWriter.WriteStartElement("se-gen-base:RavarorFornodenheterResultatrakningen");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD-1");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(RavarorOchFornodenheterResultatrakningenRESm1.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Handelsvaror Period 0
        if (!string.IsNullOrEmpty(HandelsvarorRES0.Text))
        {
            textWriter.WriteStartElement("se-gen-base:Handelsvaror");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(HandelsvarorRES0.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Handelsvaror Period -1
        if (!string.IsNullOrEmpty(HandelsvarorRESm1.Text))
        {
            textWriter.WriteStartElement("se-gen-base:Handelsvaror");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD-1");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(HandelsvarorRESm1.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Ovriga externa kostnader Period 0
        if (!string.IsNullOrEmpty(OvrigaExternaKostnaderRES0.Text))
        {
            textWriter.WriteStartElement("se-gen-base:OvrigaExternaKostnader");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(OvrigaExternaKostnaderRES0.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Ovriga externa kostnader Period -1
        if (!string.IsNullOrEmpty(OvrigaExternaKostnaderRESm1.Text))
        {
            textWriter.WriteStartElement("se-gen-base:OvrigaExternaKostnader");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD-1");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(OvrigaExternaKostnaderRESm1.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Personalkostnader Period 0
        if (!string.IsNullOrEmpty(PersonalkostnaderRES0.Text))
        {
            textWriter.WriteStartElement("se-gen-base:Personalkostnader");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(PersonalkostnaderRES0.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Personalkostnader Period -1
        if (!string.IsNullOrEmpty(PersonalkostnaderRESm1.Text))
        {
            textWriter.WriteStartElement("se-gen-base:Personalkostnader");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD-1");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(PersonalkostnaderRESm1.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Av- och nedskrivningar materiella och immateriella Period 0
        if (!string.IsNullOrEmpty(AvskrivningarOchNedskrivningarAvMateriellaOchImmateriellaAnlaggningstillgangarRES0.Text))
        {
            textWriter.WriteStartElement("se-gen-base:AvskrivningarOchNedskrivningarMateriellaOchImmateriellaAnlaggningstillgangar");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(AvskrivningarOchNedskrivningarAvMateriellaOchImmateriellaAnlaggningstillgangarRES0.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Av- och nedskrivningar materiella och immateriella Period -1
        if (!string.IsNullOrEmpty(AvskrivningarOchNedskrivningarAvMateriellaOchImmateriellaAnlaggningstillgangarRESm1.Text))
        {
            textWriter.WriteStartElement("se-gen-base:AvskrivningarOchNedskrivningarMateriellaOchImmateriellaAnlaggningstillgangar");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD-1");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(AvskrivningarOchNedskrivningarAvMateriellaOchImmateriellaAnlaggningstillgangarRESm1.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Nedskrivningar av omsattningstillgangar Period 0
        if (!string.IsNullOrEmpty(NedskrivningarAvOmsattningstillgangarUtoverNormalaNedskrivningarRES0.Text))
        {
            textWriter.WriteStartElement("se-gen-base:NedskrivningarOmsattningstillgangarUtoverNormalaNedskrivningar");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(NedskrivningarAvOmsattningstillgangarUtoverNormalaNedskrivningarRES0.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Nedskrivningar av omsattningstillgangar Period -1
        if (!string.IsNullOrEmpty(NedskrivningarAvOmsattningstillgangarUtoverNormalaNedskrivningarRESm1.Text))
        {
            textWriter.WriteStartElement("se-gen-base:NedskrivningarOmsattningstillgangarUtoverNormalaNedskrivningar");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD-1");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(NedskrivningarAvOmsattningstillgangarUtoverNormalaNedskrivningarRESm1.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Ovriga rorelsekostnader Period 0
        if (!string.IsNullOrEmpty(OvrigaRorelsekostnaderRES0.Text))
        {
            textWriter.WriteStartElement("se-gen-base:OvrigaRorelsekostnader");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(OvrigaRorelsekostnaderRES0.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Ovriga rorelsekostnader Period -1
        if (!string.IsNullOrEmpty(OvrigaRorelsekostnaderRESm1.Text))
        {
            textWriter.WriteStartElement("se-gen-base:OvrigaRorelsekostnader");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD-1");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(OvrigaRorelsekostnaderRESm1.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Summa funktioner Period 0
        if (!string.IsNullOrEmpty(SummaFunktionerRES0.Text))
        {
            textWriter.WriteStartElement("se-gen-base:FunktionerMmSumma");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(SummaFunktionerRES0.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Summa funktioner Period -1
        if (!string.IsNullOrEmpty(SummaFunktionerRESm1.Text))
        {
            textWriter.WriteStartElement("se-gen-base:FunktionerMmSumma");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD-1");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(SummaFunktionerRESm1.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Summa rorelsekostnader Period 0
        if (!string.IsNullOrEmpty(RorelsekostnaderRES0.Text))
        {
            textWriter.WriteStartElement("se-gen-base:Rorelsekostnader");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(RorelsekostnaderRES0.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Summa rorelsekostnader Period -1
        if (!string.IsNullOrEmpty(RorelsekostnaderRESm1.Text))
        {
            textWriter.WriteStartElement("se-gen-base:Rorelsekostnader");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD-1");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(RorelsekostnaderRESm1.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Rorelseresultat Period 0
        if (!string.IsNullOrEmpty(RorelseresultatRES0.Text))
        {
            textWriter.WriteStartElement("se-gen-base:Rorelseresultat");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(RorelseresultatRES0.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Rorelseresultat Period -1
        if (!string.IsNullOrEmpty(RorelseresultatRESm1.Text))
        {
            textWriter.WriteStartElement("se-gen-base:Rorelseresultat");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD-1");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(RorelseresultatRESm1.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Resultat fran andelar i koncernforetag Period 0
        if (!string.IsNullOrEmpty(ResultatFranAndelarIKoncernforetagRES0.Text))
        {
            textWriter.WriteStartElement("se-gen-base:ResultatAndelarKoncernforetag");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(ResultatFranAndelarIKoncernforetagRES0.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Resultat fran andelar i koncernforetag Period -1
        if (!string.IsNullOrEmpty(ResultatFranAndelarIKoncernforetagRESm1.Text))
        {
            textWriter.WriteStartElement("se-gen-base:ResultatAndelarKoncernforetag");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD-1");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(ResultatFranAndelarIKoncernforetagRESm1.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Resultat fran andelar i intresseforetag Period 0
        if (!string.IsNullOrEmpty(ResultatFranAndelarIIntresseforetagRES0.Text))
        {
            textWriter.WriteStartElement("se-gen-base:ResultatAndelarIntresseforetag");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(ResultatFranAndelarIIntresseforetagRES0.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Resultat fran andelar i intresseforetag Period -1
        if (!string.IsNullOrEmpty(ResultatFranAndelarIIntresseforetagRESm1.Text))
        {
            textWriter.WriteStartElement("se-gen-base:ResultatAndelarIntresseforetag");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD-1");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(ResultatFranAndelarIIntresseforetagRESm1.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Resultat fran ovriga finansiella anlaggningstillgangar Period 0
        if (!string.IsNullOrEmpty(ResultatFranOvrigaFinansiellaAnlaggningstillgangarRES0.Text))
        {
            textWriter.WriteStartElement("se-gen-base:ResultatOvrigaFinansiellaAnlaggningstillgangar");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(ResultatFranOvrigaFinansiellaAnlaggningstillgangarRES0.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Resultat fran ovriga finansiella anlaggningstillgangar Period -1
        if (!string.IsNullOrEmpty(ResultatFranOvrigaFinansiellaAnlaggningstillgangarRESm1.Text))
        {
            textWriter.WriteStartElement("se-gen-base:ResultatOvrigaFinansiellaAnlaggningstillgangar");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD-1");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(ResultatFranOvrigaFinansiellaAnlaggningstillgangarRESm1.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Ovriga ranteintakter och liknande resultatposter Period 0
        if (!string.IsNullOrEmpty(OvrigaRanteintakterOchLiknandeResultatposterRES0.Text))
        {
            textWriter.WriteStartElement("se-gen-base:OvrigaRanteintakterOchLiknandeResultatposter");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(OvrigaRanteintakterOchLiknandeResultatposterRES0.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Ovriga ranteintakter och liknande resultatposter Period -1
        if (!string.IsNullOrEmpty(OvrigaRanteintakterOchLiknandeResultatposterRESm1.Text))
        {
            textWriter.WriteStartElement("se-gen-base:OvrigaRanteintakterOchLiknandeResultatposter");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD-1");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(OvrigaRanteintakterOchLiknandeResultatposterRESm1.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Nedskrivningar av finansiella anlaggningstillgangar Period 0
        if (!string.IsNullOrEmpty(NedskrivningarAvFinansiellaAnlaggningstillgangarOchKortfristigaPlaceringarRES0.Text))
        {
            textWriter.WriteStartElement("se-gen-base:NedskrivningarFinansiellaAnlaggningstillgangarOchKortfristigaPlaceringar");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(NedskrivningarAvFinansiellaAnlaggningstillgangarOchKortfristigaPlaceringarRES0.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Nedskrivningar av finansiella anlaggningstillgangar Period -1
        if (!string.IsNullOrEmpty(NedskrivningarAvFinansiellaAnlaggningstillgangarOchKortfristigaPlaceringarRESm1.Text))
        {
            textWriter.WriteStartElement("se-gen-base:NedskrivningarFinansiellaAnlaggningstillgangarOchKortfristigaPlaceringar");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD-1");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(NedskrivningarAvFinansiellaAnlaggningstillgangarOchKortfristigaPlaceringarRESm1.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Rantekostnader och liknande resultatposter Period 0
        if (!string.IsNullOrEmpty(RantekostnaderOchLiknandeResultatposterRES0.Text))
        {
            textWriter.WriteStartElement("se-gen-base:RantekostnaderOchLiknandeResultatposter");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(RantekostnaderOchLiknandeResultatposterRES0.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Rantekostnader och liknande resultatposter Period -1
        if (!string.IsNullOrEmpty(RantekostnaderOchLiknandeResultatposterRESm1.Text))
        {
            textWriter.WriteStartElement("se-gen-base:RantekostnaderOchLiknandeResultatposter");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD-1");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(RantekostnaderOchLiknandeResultatposterRESm1.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Resultat efter finansiella poster Period 0
        if (!string.IsNullOrEmpty(ResultatEfterFinansiellaPosterRES0.Text))
        {
            textWriter.WriteStartElement("se-gen-base:ResultatEfterFinansiellaPoster");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(ResultatEfterFinansiellaPosterRES0.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Resultat efter finansiella poster Period -1
        if (!string.IsNullOrEmpty(ResultatEfterFinansiellaPosterRESm1.Text))
        {
            textWriter.WriteStartElement("se-gen-base:ResultatEfterFinansiellaPoster");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD-1");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(ResultatEfterFinansiellaPosterRESm1.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Summa finansiella poster Period 0
        if (!string.IsNullOrEmpty(SummaFinPosterRES0.Text))
        {
            textWriter.WriteStartElement("se-gen-base:FinansiellaPosterSumma");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(SummaFinPosterRES0.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Summa finansiella poster Period -1
        if (!string.IsNullOrEmpty(SummaFinPosterRESm1.Text))
        {
            textWriter.WriteStartElement("se-gen-base:FinansiellaPosterSumma");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD-1");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(SummaFinPosterRESm1.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Extraordinara intakter Period 0
        if (!string.IsNullOrEmpty(ExtraordinaraIntakterRES0.Text))
        {
            textWriter.WriteStartElement("se-gen-base:ExtraordinaraIntakter");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(ExtraordinaraIntakterRES0.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Extraordinara intakter Period -1
        if (!string.IsNullOrEmpty(ExtraordinaraIntakterRESm1.Text))
        {
            textWriter.WriteStartElement("se-gen-base:ExtraordinaraIntakter");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD-1");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(ExtraordinaraIntakterRESm1.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Extraordinara kostnader Period 0
        if (!string.IsNullOrEmpty(ExtraordinaraKostnaderRES0.Text))
        {
            textWriter.WriteStartElement("se-gen-base:ExtraordinaraKostnader");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(ExtraordinaraKostnaderRES0.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Extraordinara kostnader Period -1
        if (!string.IsNullOrEmpty(ExtraordinaraKostnaderRESm1.Text))
        {
            textWriter.WriteStartElement("se-gen-base:ExtraordinaraKostnader");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD-1");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(ExtraordinaraKostnaderRESm1.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Resultat fore bokslutsdispositioner och skatt Period 0
        if (!string.IsNullOrEmpty(ResultatForeBokslutsdispositionerOchSkattRES0.Text))
        {
            textWriter.WriteStartElement("se-gen-base:ResultatForeBokslutsdispositionerOchSkatt");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(ResultatForeBokslutsdispositionerOchSkattRES0.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Resultat fore bokslutsdispositioner och skatt Period -1
        if (!string.IsNullOrEmpty(ResultatForeBokslutsdispositionerOchSkattRESm1.Text))
        {
            textWriter.WriteStartElement("se-gen-base:ResultatForeBokslutsdispositionerOchSkatt");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD-1");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(ResultatForeBokslutsdispositionerOchSkattRESm1.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Forandring av periodiseringsfond Period 0
        if (!string.IsNullOrEmpty(ForandringAvPeriodiseringsfondRES0.Text))
        {
            textWriter.WriteStartElement("se-gen-base:ForandringPeriodiseringsfond");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(ForandringAvPeriodiseringsfondRES0.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Forandring av periodiseringsfond Period -1
        if (!string.IsNullOrEmpty(ForandringAvPeriodiseringsfondRESm1.Text))
        {
            textWriter.WriteStartElement("se-gen-base:ForandringPeriodiseringsfond");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD-1");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(ForandringAvPeriodiseringsfondRESm1.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Forandring av overavskrivningar Period 0
        if (!string.IsNullOrEmpty(ForandringAvOveravskrivningarRES0.Text))
        {
            textWriter.WriteStartElement("se-gen-base:ForandringOveravskrivningar");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(ForandringAvOveravskrivningarRES0.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Forandring av overavskrivningar Period -1
        if (!string.IsNullOrEmpty(ForandringAvOveravskrivningarRESm1.Text))
        {
            textWriter.WriteStartElement("se-gen-base:ForandringOveravskrivningar");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD-1");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(ForandringAvOveravskrivningarRESm1.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Erhallna koncernbidrag Period 0
        if (!string.IsNullOrEmpty(ErhallnaKoncernbidragRES0.Text))
        {
            textWriter.WriteStartElement("se-gen-base:ErhallnaKoncernbidrag");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(ErhallnaKoncernbidragRES0.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Erhallna koncernbidrag Period -1
        if (!string.IsNullOrEmpty(ErhallnaKoncernbidragRESm1.Text))
        {
            textWriter.WriteStartElement("se-gen-base:ErhallnaKoncernbidrag");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD-1");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(ErhallnaKoncernbidragRESm1.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Lamnade koncernbidrag Period 0
        if (!string.IsNullOrEmpty(LamnadeKoncernbidragRES0.Text))
        {
            textWriter.WriteStartElement("se-gen-base:LamnadeKoncernbidrag");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(LamnadeKoncernbidragRES0.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Lamnade koncernbidrag Period -1
        if (!string.IsNullOrEmpty(LamnadeKoncernbidragRESm1.Text))
        {
            textWriter.WriteStartElement("se-gen-base:LamnadeKoncernbidrag");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD-1");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(LamnadeKoncernbidragRESm1.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Ovriga bokslutsdispositioner Period 0
        if (!string.IsNullOrEmpty(OvrigaBokslutsdispositionerRES0.Text))
        {
            textWriter.WriteStartElement("se-gen-base:OvrigaBokslutsdispositioner");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(OvrigaBokslutsdispositionerRES0.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Ovriga bokslutsdispositioner Period -1
        if (!string.IsNullOrEmpty(OvrigaBokslutsdispositionerRESm1.Text))
        {
            textWriter.WriteStartElement("se-gen-base:OvrigaBokslutsdispositioner");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD-1");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(OvrigaBokslutsdispositionerRESm1.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Summa bokslutsdispositioner Period 0
        if (!string.IsNullOrEmpty(SummaBokslutsdispositionerRES0.Text))
        {
            textWriter.WriteStartElement("se-gen-base:BokslutsdispositionerSumma");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(SummaBokslutsdispositionerRES0.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Summa bokslutsdispositioner Period -1
        if (!string.IsNullOrEmpty(SummaBokslutsdispositionerRESm1.Text))
        {
            textWriter.WriteStartElement("se-gen-base:BokslutsdispositionerSumma");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD-1");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(SummaBokslutsdispositionerRESm1.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Resultat fore skatt Period 0
        if (!string.IsNullOrEmpty(ResultatForeSkattRES0.Text))
        {
            textWriter.WriteStartElement("se-gen-base:ResultatForeSkatt");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(ResultatForeSkattRES0.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Resultat fore skatt Period -1
        if (!string.IsNullOrEmpty(ResultatForeSkattRESm1.Text))
        {
            textWriter.WriteStartElement("se-gen-base:ResultatForeSkatt");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD-1");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(ResultatForeSkattRESm1.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Skatt pa arets resultat Period 0
        if (!string.IsNullOrEmpty(SkattPaAretsResultatRES0.Text))
        {
            textWriter.WriteStartElement("se-gen-base:SkattAretsResultat");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(SkattPaAretsResultatRES0.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Skatt pa arets resultat Period -1
        if (!string.IsNullOrEmpty(SkattPaAretsResultatRESm1.Text))
        {
            textWriter.WriteStartElement("se-gen-base:SkattAretsResultat");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD-1");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(SkattPaAretsResultatRESm1.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Ovriga skatter Period 0
        if (!string.IsNullOrEmpty(OvrigaSkatterRES0.Text))
        {
            textWriter.WriteStartElement("se-gen-base:OvrigaSkatter");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(OvrigaSkatterRES0.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Ovriga skatter Period -1
        if (!string.IsNullOrEmpty(OvrigaSkatterRESm1.Text))
        {
            textWriter.WriteStartElement("se-gen-base:OvrigaSkatter");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD-1");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(OvrigaSkatterRESm1.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Arets resultat Period 0
        if (!string.IsNullOrEmpty(AretsResultatRES0.Text))
        {
            textWriter.WriteStartElement("se-gen-base:AretsResultat");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(AretsResultatRES0.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Resultatrakning Arets resultat Period -1
        if (!string.IsNullOrEmpty(AretsResultatRESm1.Text))
        {
            textWriter.WriteStartElement("se-gen-base:AretsResultat");
            textWriter.WriteAttributeString("decimals", txtDecimals.Text);
            textWriter.WriteAttributeString("contextRef", "PERIOD-1");
            textWriter.WriteAttributeString("unitRef", "valuta");
            textWriter.WriteString(AretsResultatRESm1.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Ort for untertecknande
        if (!string.IsNullOrEmpty(OrtUndertecknande.Text))
        {
            textWriter.WriteStartElement("se-gen-base:UndertecknandeAvArsredovisningOrt");
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteString(OrtUndertecknande.Text);
            textWriter.WriteEndElement();
        }

        //Insert Elements for Datum for untertecknande
        if (!string.IsNullOrEmpty(DatumUndertecknande.Text))
        {
            textWriter.WriteStartElement("se-gen-base:UndertecknandeAvArsredovisningDatum");
            textWriter.WriteAttributeString("contextRef", "PERIOD0");
            textWriter.WriteString(DatumUndertecknande.Text);
            textWriter.WriteEndElement();
        }

        //End Everything
        textWriter.WriteEndDocument();

        //Clean up
        textWriter.Flush();
        textWriter.Close();

        // IF WE WANT THE USER TO BE ABLE TO DOWNLOAD THE XML-FILE directly (uncomment the code below)
        //Response.ContentType = "Application/xbrl";
        //Response.AppendHeader("Content-Disposition", "attachment; filename=Report.xbrl");
        //Response.Flush();
        //Response.Close();

        // Redirect the user to a new webpage
        Server.Transfer("List-of-xml-files.aspx");
    }

    protected void txtBeloppsformat_SelectedIndexChanged(object sender, EventArgs e)
    {
        if (txtBeloppsformat.SelectedValue == "NORMALFORM")
        {
            txtDecimals.Text = "INF";
        }
        else
        {
            txtDecimals.Text = "-3";
        }
    }
}
